@@ -15,7 +15,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '2.4-6'                              #
+# last changed in version = '2.4-7'                              #
 #                                                                # 
 ##################################################################
 
@@ -128,7 +128,7 @@ if [ "$1" == 'decryptWEP' ]; then
 fi 
 
 if  [ "$1" == 'reaver' ]; then 
-    reaver -i wlan0 -b $2 -c $3 -e $4 -a -E -vv 
+    reaver -i wlan0 -b $2 -e $3 -a -E -vv 
 fi 
 
 if  [ "$1" == 'wash' ]; then 
