@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '2.4'
-Build = '5'
+Build = '7'
 
 import sys
 import os
@@ -339,7 +339,7 @@ class clevenCapture(QtGui.QMainWindow):
        '''Opens an xterm window that sends authentication packets.'''
        
        # print "reaver -i wlan0 -b ",bssid," -c ",channel," -e ",essid," -a -E -vv" 
-       os.system('osso-xterm -e "sudo %s/%s reaver %s %s %s" &' % (pathMain, helperScript, bssid, channel, essid))
+       os.system('osso-xterm -e "sudo %s/%s reaver %s %s" &' % (pathMain, helperScript, bssid, essid))
        
 class clevenConfigureDrivers(QtGui.QDialog):
 
@@ -540,18 +540,16 @@ class clevenSelectDictionary(QtGui.QDialog):
        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
-       QtCore.QObject.connect(self.ui.dictionaryList, QtCore.SIGNAL('itemSelectionChanged()'), self.setDictionary)
-       
        self.ui.dictionaryList.clear()     
        dlist = os.listdir(pathStorage + '/' + folderDictionaries)
        self.ui.dictionaryList.addItems(dlist)
-       
-    def setDictionary(self):
+
+    def closeEvent(self, event):
+       '''Store selection on close'''
+       event.accept()
        global myDictionary
        myDictionary = self.ui.dictionaryList.currentItem().text()
-
-       self.close()
-
+       
 class clevenManageCaptured(QtGui.QMainWindow):
 
     def __init__(self, parent=None):
